<div>
    
    <!--

      <table class="table">
          <thead>
          <tr>
              <th>Metric</th>
              <th>Value</th>
          </tr>
          </thead>
          <tbody>
          <tr *ngFor="let stat of stats">
              <td>{{stat.desc}}</td>
              <td>{{stat.value}}</td>
          </tr>

          </tbody>
      </table>

      <div class="btn-toolbar">
          <div class="btn-group">
              <div class="btn btn-default" (click)='loader.load()'>
                  Refresh
              </div>
          </div>
      </div>
      <br/>
      -->

</div>
