/* tslint:disable:no-unused-variable */
import { async, ComponentFixture, TestBed } from "@angular/core/testing"
import { By } from "@angular/platform-browser"
import { DebugElement } from "@angular/core"

import { DashboardStatsComponent } from "./dashboard-stats.component"

describe("DashboardStatsComponent", () => {
    let component: DashboardStatsComponent
    let fixture: ComponentFixture<DashboardStatsComponent>
    
    beforeEach(async(() => {
        TestBed.configureTestingModule({
            declarations: [DashboardStatsComponent]
        })
            .compileComponents()
    }))
    
    beforeEach(() => {
        fixture = TestBed.createComponent(DashboardStatsComponent)
        component = fixture.componentInstance
        fixture.detectChanges()
    })
    
    it("should create", () => {
        expect(component)
            .toBeTruthy()
    })
})
